=== modified file 'account_reconciliation/account_move_line.py'
--- account_reconciliation/account_move_line.py	2013-06-25 09:30:24 +0000
+++ account_reconciliation/account_move_line.py	2013-11-28 13:48:07 +0000
@@ -22,6 +22,7 @@
 ##############################################################################
 
 from osv import osv
+from osv import fields
 import time
 import netsvc
 from tools.translate import _
@@ -85,7 +86,16 @@
                 raise osv.except_osv(_('Warning !'), _('To reconcile the entries company should be the same for all entries'))
             company_list.append(line.company_id.id)
 
+        # UTP-752: Add an attribute to reconciliation element if different instance levels
+        previous_level = False
+        different_level = False
         for line in self.browse(cr, uid, ids, context=context):
+            # Do level check only if we don't know if more than 1 different level exists between lines
+            if not different_level:
+                if not previous_level:
+                    previous_level = line.instance_id.level
+                if previous_level != line.instance_id.level:
+                    different_level = True
             company_currency_id = line.company_id.currency_id
             if line.reconcile_id:
                 raise osv.except_osv(_('Warning'), _('Already Reconciled!'))
@@ -100,12 +110,14 @@
             else:
                 unmerge.append(line.id)
                 total += (line.debit_currency or 0.0) - (line.credit_currency or 0.0)
+
         if self.pool.get('res.currency').is_zero(cr, uid, company_currency_id, total):
             res = self.reconcile(cr, uid, merges+unmerge, context=context)
             return res
         r_id = move_rec_obj.create(cr, uid, {
             'type': type,
-            'line_partial_ids': map(lambda x: (4,x,False), merges+unmerge)
+            'line_partial_ids': map(lambda x: (4,x,False), merges+unmerge),
+            'is_multi_instance': different_level,
         })
         
         # UF-2011: synchronize move lines (not "marked" after reconcile creation)
@@ -135,10 +147,20 @@
         if context is None:
             context = {}
         company_list = []
+        # Check company's field
+        # UTP-752: Check if lines comes from the same instance level
+        previous_level = False
+        different_level = False
         for line in self.browse(cr, uid, ids, context=context):
             if company_list and not line.company_id.id in company_list:
                 raise osv.except_osv(_('Warning !'), _('To reconcile the entries company should be the same for all entries'))
             company_list.append(line.company_id.id)
+            # instance level
+            if not different_level:
+                if not previous_level:
+                    previous_level = line.instance_id.level
+                if previous_level != line.instance_id.level:
+                    different_level = True
         for line in unrec_lines:
             if line.state <> 'valid':
                 raise osv.except_osv(_('Error'),
@@ -187,7 +209,8 @@
         r_id = move_rec_obj.create(cr, uid, {
             'type': type,
             'line_id': map(lambda x: (4, x, False), ids),
-            'line_partial_ids': map(lambda x: (3, x, False), ids)
+            'line_partial_ids': map(lambda x: (3, x, False), ids),
+            'is_multi_instance': different_level,
         })
         
         # UF-2011: synchronize move lines (not "marked" after reconcile creation)
@@ -279,6 +302,14 @@
     _name = 'account.move.reconcile'
     _inherit = 'account.move.reconcile'
 
+    _columns = {
+        'is_multi_instance': fields.boolean(string="Reconcile at least 2 lines that comes from different instance levels."),
+    }
+
+    _defaults = {
+        'is_multi_instance': lambda *a: False,
+    }
+
     def create(self, cr, uid, vals, context=None):
         """
         Write reconcile_txt on linked account_move_lines if any changes on this reconciliation.

